@@ -46,7 +46,7 @@ static void e_minicard_finalize (GObject *object);
 static gboolean e_minicard_event (GnomeCanvasItem *item, GdkEvent *event);
 static void e_minicard_realize (GnomeCanvasItem *item);
 static void e_minicard_reflow (GnomeCanvasItem *item, gint flags);
-static void e_minicard_style_updated (EMinicard *minicard);
+static void e_minicard_style_set (EMinicard *minicard, GtkStyle *previous_style);
 
 static void e_minicard_resize_children (EMinicard *e_minicard);
 static void remodel (EMinicard *e_minicard);
@@ -79,7 +79,7 @@ enum {
 	SELECTED,
 	DRAG_BEGIN,
 	OPEN_CONTACT,
-	STYLE_UPDATED,
+	STYLE_SET,
 	LAST_SIGNAL
 };
 
@@ -114,7 +114,7 @@ e_minicard_class_init (EMinicardClass *class)
 	item_class->realize = e_minicard_realize;
 	item_class->event = e_minicard_event;
 
-	class->style_updated = e_minicard_style_updated;
+	class->style_set = e_minicard_style_set;
 	class->selected = NULL;
 
 	g_object_class_install_property (
@@ -220,14 +220,15 @@ e_minicard_class_init (EMinicardClass *class)
 		G_TYPE_NONE, 1,
 		E_TYPE_CONTACT);
 
-	signals[STYLE_UPDATED] = g_signal_new (
-		"style_updated",
+	signals[STYLE_SET] = g_signal_new (
+		"style_set",
 		G_TYPE_FROM_CLASS (object_class),
 		G_SIGNAL_RUN_FIRST,
-		G_STRUCT_OFFSET (EMinicardClass, style_updated),
+		G_STRUCT_OFFSET (EMinicardClass, style_set),
 		NULL, NULL,
-		g_cclosure_marshal_VOID__VOID,
-		G_TYPE_NONE, 0);
+		g_cclosure_marshal_VOID__OBJECT,
+		G_TYPE_NONE, 1,
+		GTK_TYPE_STYLE);
 
 	/* init the accessibility support for e_minicard */
 	e_minicard_a11y_init ();
@@ -259,43 +260,37 @@ static void
 set_selected (EMinicard *minicard,
               gboolean selected)
 {
-	GtkWidget *widget;
-	GdkColor outline, header, text;
+	GnomeCanvas *canvas;
+	GtkStyle *style;
 
-	widget = GTK_WIDGET (GNOME_CANVAS_ITEM (minicard)->canvas);
+	canvas = GNOME_CANVAS_ITEM (minicard)->canvas;
+	style = gtk_widget_get_style (GTK_WIDGET (canvas));
 
 	if (selected) {
-		e_utils_get_theme_color_color (widget, "theme_selected_bg_color", E_UTILS_DEFAULT_THEME_SELECTED_BG_COLOR, &outline);
-		e_utils_get_theme_color_color (widget, "theme_selected_bg_color", E_UTILS_DEFAULT_THEME_SELECTED_BG_COLOR, &header);
-		e_utils_get_theme_color_color (widget, "theme_selected_fg_color", E_UTILS_DEFAULT_THEME_SELECTED_FG_COLOR, &text);
-
 		gnome_canvas_item_set (
 			minicard->rect,
-			"outline_color_gdk", &outline,
+			"outline_color_gdk", &style->bg[GTK_STATE_ACTIVE],
 			NULL);
 		gnome_canvas_item_set (
 			minicard->header_rect,
-			"fill_color_gdk", &header,
+			"fill_color_gdk", &style->bg[GTK_STATE_SELECTED],
 			NULL);
 		gnome_canvas_item_set (
 			minicard->header_text,
-			"fill_color_gdk", &text,
+			"fill_color_gdk", &style->text[GTK_STATE_SELECTED],
 			NULL);
 	} else {
-		e_utils_get_theme_color_color (widget, "theme_bg_color", E_UTILS_DEFAULT_THEME_BG_COLOR, &header);
-		e_utils_get_theme_color_color (widget, "theme_text_color,theme_fg_color", E_UTILS_DEFAULT_THEME_TEXT_COLOR, &text);
-
 		gnome_canvas_item_set (
 			minicard->rect,
 			"outline_color", NULL,
 			NULL);
 		gnome_canvas_item_set (
 			minicard->header_rect,
-			"fill_color_gdk", &header,
+			"fill_color_gdk", &style->bg[GTK_STATE_NORMAL],
 			NULL);
 		gnome_canvas_item_set (
 			minicard->header_text,
-			"fill_color_gdk", &text,
+			"fill_color_gdk", &style->text[GTK_STATE_NORMAL],
 			NULL);
 	}
 	minicard->selected = selected;
@@ -479,7 +474,8 @@ e_minicard_finalize (GObject *object)
 }
 
 static void
-e_minicard_style_updated (EMinicard *minicard)
+e_minicard_style_set (EMinicard *minicard,
+                      GtkStyle *previous_style)
 {
 	GnomeCanvasItem *item = GNOME_CANVAS_ITEM (minicard);
 
@@ -492,10 +488,15 @@ e_minicard_realize (GnomeCanvasItem *item)
 {
 	EMinicard *e_minicard;
 	GnomeCanvasGroup *group;
+	GnomeCanvas *canvas;
+	GtkStyle *style;
 
 	e_minicard = E_MINICARD (item);
 	group = GNOME_CANVAS_GROUP (item);
 
+	canvas = GNOME_CANVAS_ITEM (item)->canvas;
+	style = gtk_widget_get_style (GTK_WIDGET (canvas));
+
 	GNOME_CANVAS_ITEM_CLASS (e_minicard_parent_class)->realize (item);
 
 	e_minicard->rect = gnome_canvas_item_new (
@@ -515,7 +516,7 @@ e_minicard_realize (GnomeCanvasItem *item)
 		"y1", (gdouble) 2,
 		"x2", (gdouble) MAX (e_minicard->width - 3, 0),
 		"y2", (gdouble) MAX (e_minicard->height - 3, 0),
-		"fill_color_gdk", NULL,
+		"fill_color_gdk", &style->bg[GTK_STATE_NORMAL],
 		NULL);
 
 	e_minicard->header_text = gnome_canvas_item_new (
@@ -524,7 +525,7 @@ e_minicard_realize (GnomeCanvasItem *item)
 		"width", (gdouble) MAX (e_minicard->width - 12, 0),
 		"clip", TRUE,
 		"use_ellipsis", TRUE,
-		"fill_color_gdk", NULL,
+		"fill_color_gdk", &style->fg[GTK_STATE_NORMAL],
 		"text", "",
 		NULL);
 
