@@ -602,14 +602,6 @@ em_utils_composer_send_cb (EMsgComposer *composer,
 	AsyncContext *async_context;
 	GCancellable *cancellable;
 
-	if (!camel_session_get_online (CAMEL_SESSION (session))) {
-		e_alert_run_dialog_for_args (
-			GTK_WINDOW (composer),
-			"mail-composer:saving-to-outbox", NULL);
-		e_msg_composer_save_to_outbox (composer);
-		return;
-	}
-
 	async_context = g_slice_new0 (AsyncContext);
 	async_context->message = g_object_ref (message);
 	async_context->composer = g_object_ref (composer);
@@ -1758,12 +1750,6 @@ forward_non_attached (EMailBackend *backend,
 	shell = e_shell_backend_get_shell (E_SHELL_BACKEND (backend));
 
 	forward = quoting_text (QUOTING_FORWARD);
-	if (style == E_MAIL_FORWARD_STYLE_INLINE && forward) {
-		gchar *tmp = forward;
-		forward = g_strconcat (forward, "<br>", NULL);
-		g_free (tmp);
-	}
-
 	text = em_utils_message_to_html (
 		CAMEL_SESSION (session), message,
 		forward, flags, NULL, NULL, &validity_found);
@@ -2124,7 +2110,7 @@ reply_get_composer (EShell *shell,
 	if ((subject = (gchar *) camel_mime_message_get_subject (message))) {
 		gboolean skip_len = -1;
 
-		if (em_utils_is_re_in_subject (subject, &skip_len, NULL) && skip_len > 0)
+		if (em_utils_is_re_in_subject (subject, &skip_len) && skip_len > 0)
 			subject = subject + skip_len;
 
 		subject = g_strdup_printf ("Re: %s", subject);
@@ -3044,18 +3030,22 @@ post_header_clicked_cb (EComposerPostHeader *header,
 	EMFolderTree *folder_tree;
 	GtkWidget *dialog;
 	GList *list;
+	const gchar *caption;
 
 	/* FIXME Limit the folder tree to the NNTP account? */
 	model = em_folder_tree_model_get_default ();
 
 	dialog = em_folder_selector_new (
-		/* FIXME GTK_WINDOW (composer) */ NULL,
-		model, EM_FOLDER_SELECTOR_CAN_CREATE,
-		_("Posting destination"),
-		_("Choose folders to post the message to."),
-		NULL);
+		/* FIXME GTK_WINDOW (composer) */ NULL, model);
+
+	gtk_window_set_title (GTK_WINDOW (dialog), _("Posting destination"));
 
 	selector = EM_FOLDER_SELECTOR (dialog);
+	em_folder_selector_set_can_create (selector, TRUE);
+
+	caption = _("Choose folders to post the message to.");
+	em_folder_selector_set_caption (selector, caption);
+
 	folder_tree = em_folder_selector_get_folder_tree (selector);
 
 	em_folder_tree_set_excluded (
