@@ -531,6 +531,8 @@ build_dialog (GtkWindow *parent,
 		"/org/gnome/evolution/mail/send-recv-window/",
 		E_RESTORE_WINDOW_SIZE);
 
+	gtk_widget_ensure_style ((GtkWidget *) gd);
+
 	container = gtk_dialog_get_action_area (gd);
 	gtk_container_set_border_width (GTK_CONTAINER (container), 6);
 
@@ -1112,19 +1114,15 @@ receive_update_got_folderinfo (GObject *source_object,
 
 	/* Ignore cancellations. */
 	if (g_error_matches (local_error, G_IO_ERROR, G_IO_ERROR_CANCELLED)) {
-		g_warn_if_fail (info == NULL);
+		g_warn_if_fail (info != NULL);
 		g_error_free (local_error);
 
-		receive_done (send_info);
-
 	/* XXX Need to hand this off to an EAlertSink. */
 	} else if (local_error != NULL) {
-		g_warn_if_fail (info == NULL);
+		g_warn_if_fail (info != NULL);
 		g_warning ("%s: %s", G_STRFUNC, local_error->message);
 		g_error_free (local_error);
 
-		receive_done (send_info);
-
 	/* CamelFolderInfo may be NULL even if no error occurred. */
 	} else if (info != NULL) {
 		GPtrArray *folders = g_ptr_array_new ();
