@@ -439,75 +439,66 @@ sao_folders_add_button_clicked_cb (GtkButton *button,
 	window = GTK_WINDOW (gtk_widget_get_toplevel (widget));
 
 	dialog = em_folder_selector_new (
-		window, em_folder_tree_model_get_default (),
-		0, _("Select Folder to Add"), NULL, _("_Add"));
+		window, em_folder_tree_model_get_default ());
+
+	gtk_window_set_title (
+		GTK_WINDOW (dialog), _("Select Folder to Add"));
 
 	selector = EM_FOLDER_SELECTOR (dialog);
-	folder_tree = em_folder_selector_get_folder_tree (selector);
+	em_folder_selector_set_default_button_label (selector, _("_Add"));
 
-	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (folder_tree));
-	gtk_tree_selection_set_mode (selection, GTK_SELECTION_MULTIPLE);
+	folder_tree = em_folder_selector_get_folder_tree (selector);
 
 	em_folder_tree_set_excluded (folder_tree, EMFT_EXCLUDE_NOSELECT);
 
 	if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_OK) {
-		GList *list, *folder_uris;
+		const gchar *uri;
 
-		model = gtk_tree_view_get_model (tree_view);
+		uri = em_folder_selector_get_selected_uri (selector);
+		if (uri && *uri) {
+			gboolean found = FALSE;
 
-		folder_uris = em_folder_tree_get_selected_uris (folder_tree);
+			selection = gtk_tree_view_get_selection (tree_view);
+			model = gtk_tree_view_get_model (tree_view);
 
-		for (list = folder_uris; list; list = g_list_next (list)) {
-			const gchar *uri = list->data;
+			if (gtk_tree_model_get_iter_first (model, &iter)) {
+				do {
+					gchar *old_uri = NULL;
 
-			if (uri && *uri) {
-				gboolean found = FALSE;
+					gtk_tree_model_get (model, &iter, 1, &old_uri, -1);
 
-				if (gtk_tree_model_get_iter_first (model, &iter)) {
-					do {
-						gchar *old_uri = NULL;
+					found = g_strcmp0 (uri, old_uri) == 0;
 
-						gtk_tree_model_get (model, &iter, 1, &old_uri, -1);
-
-						found = g_strcmp0 (uri, old_uri) == 0;
-
-						g_free (old_uri);
-					} while (!found && gtk_tree_model_iter_next (model, &iter));
-				}
-
-				if (!found) {
-					EMailSendAccountOverride *account_override;
-					GtkListStore *list_store;
-					CamelSession *session;
-					gchar *markup;
-
-					list_store = GTK_LIST_STORE (model);
-					session = g_object_get_data (G_OBJECT (builder), MAIL_CAMEL_SESSION_KEY);
-					markup = e_mail_folder_uri_to_markup (session, uri, NULL);
-
-					gtk_list_store_append (list_store, &iter);
-					gtk_list_store_set (list_store, &iter, 0, markup, 1, uri, -1);
-
-					g_free (markup);
-
-					sao_block_changed_handler (builder);
-
-					account_override = g_object_get_data (G_OBJECT (builder), MAIL_SEND_ACCOUNT_OVERRIDE_KEY);
-					e_mail_send_account_override_set_for_folder (account_override, uri, account_uid);
-
-					sao_unblock_changed_handler (builder);
-				}
-
-				if (!list->next) {
-					selection = gtk_tree_view_get_selection (tree_view);
-
-					gtk_tree_selection_unselect_all (selection);
-					gtk_tree_selection_select_iter (selection, &iter);
-				}
+					g_free (old_uri);
+				} while (!found && gtk_tree_model_iter_next (model, &iter));
 			}
-		}
 
-		g_list_free_full (folder_uris, g_free);
+			if (!found) {
+				EMailSendAccountOverride *account_override;
+				GtkListStore *list_store;
+				CamelSession *session;
+				gchar *markup;
+
+				list_store = GTK_LIST_STORE (model);
+				session = g_object_get_data (G_OBJECT (builder), MAIL_CAMEL_SESSION_KEY);
+				markup = e_mail_folder_uri_to_markup (session, uri, NULL);
+
+				gtk_list_store_append (list_store, &iter);
+				gtk_list_store_set (list_store, &iter, 0, markup, 1, uri, -1);
+
+				g_free (markup);
+
+				sao_block_changed_handler (builder);
+
+				account_override = g_object_get_data (G_OBJECT (builder), MAIL_SEND_ACCOUNT_OVERRIDE_KEY);
+				e_mail_send_account_override_set_for_folder (account_override, uri, account_uid);
+
+				sao_unblock_changed_handler (builder);
+			}
+
+			gtk_tree_selection_unselect_all (selection);
+			gtk_tree_selection_select_iter (selection, &iter);
+		}
 	}
 
 	gtk_widget_destroy (dialog);
@@ -1055,7 +1046,8 @@ em_composer_prefs_construct (EMComposerPrefs *prefs,
 
 	/* Make sure our custom widget classes are registered with
 	 * GType before we load the GtkBuilder definition file. */
-	g_type_ensure (E_TYPE_MAIL_JUNK_OPTIONS);
+	E_TYPE_MAIL_JUNK_OPTIONS;
+	EM_TYPE_FOLDER_SELECTION_BUTTON;
 
 	prefs->builder = gtk_builder_new ();
 	e_load_ui_builder_definition (prefs->builder, "mail-config.ui");
